@@ -1,6 +1,12 @@
 from django.db import models
 
 
+class TextChoices(models.TextChoices):
+    @classmethod
+    def list_codes(cls):
+        return [code for code, label in cls.choices]
+
+
 class AbstractCreatedUpdatedModel(models.Model):
     created_at = models.DateTimeField("crée le", auto_now_add=True)
     updated_at = models.DateTimeField("maj le", auto_now=True)
